#
# spec file for package python-rnginline
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  test
Name:           python-rnginline
Version:        1.0.0
Release:        2.2
Summary:        Python libary to flatten multi-file RELAX NG schemas
License:        Apache-2.0
URL:            https://github.com/h4l/rnginline
Source:         https://files.pythonhosted.org/packages/source/r/rnginline/rnginline-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-docopt
Requires:       python-importlib_metadata >= 6.6.0
Requires:       python-lxml
Requires:       python-typing_extensions >= 4.5.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
Suggests:       python-coverage
Suggests:       python-mock
Suggests:       python-pytest >= 2.6.4
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module docopt}
BuildRequires:  %{python_module importlib_metadata >= 6.6.0}
BuildRequires:  %{python_module importlib_resources >= 5.12.0}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing_extensions >= 4.5.0}
%endif
%python_subpackages

%description
The rnginline package is a Python library and command-line tool for
multi-file RELAX NG schemas from arbitary URLs, and flattening them
into a single RELAX NG schema.

%prep
%setup -q -n rnginline-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/rnginline
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
pushd rnginline
%pytest
%endif

%post
%python_install_alternative rnginline

%postun
%python_uninstall_alternative rnginline

%files %{python_files}
%license LICENSE.txt
%doc README.md
%python_alternative %{_bindir}/rnginline
%{python_sitelib}/rnginline
%{python_sitelib}/rnginline-%{version}.dist-info

%changelog
* Mon Mar 18 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add missing importlib_metadata to {Build,}Requires.
- Less globs in %%files.
* Mon Jun  5 2023 pgajdos@suse.com
- version update to 1.0.0
  * Changed
    Supported Python versions are now 3.7 – 3.11 (inclusive)
    Project codebase & tooling refreshed
    Get rnginline.__version__ / rnginline --version from package metadata instead of hardcoding it.
  * Fixed
    Handle indirectly-included components when overriding (#5)
    Thanks to takesson for reporting this and providing a test case to demonstrate the issue.
    Resolved deprecation warnings from:
    old string escape syntax
    pkg_resources module (we now use importlib_resources)
    docopt (we now use docopt-ng)
- python-six is not required
* Fri Oct  8 2021 pgajdos@suse.com
- actually test the package, use %%pytest macro
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Dec 18 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Sep  7 2017 toddrme2178@gmail.com
- initial version
